@@ -27,6 +27,14 @@ from glances.logger import logger
 
 import psutil
 
+# This constant defines the list of available processes sort key
+sort_processes_key_list = ['cpu_percent',
+                           'memory_percent',
+                           'username',
+                           'cpu_times',
+                           'io_counters',
+                           'name']
+
 
 class GlancesProcesses(object):
     """Get processed stats using the psutil library."""
@@ -339,7 +347,7 @@ class GlancesProcesses(object):
                         try:
                             extended['memory_swap'] = sum([v.swap for v in top_process.memory_maps()])
                         except (psutil.NoSuchProcess, KeyError):
-                            # KeyError catch for issue #1551)
+                            # (KeyError catch for issue #1551)
                             pass
                         except (psutil.AccessDenied, NotImplementedError):
                             # NotImplementedError: /proc/${PID}/smaps file doesn't exist
